@@ -19,13 +19,15 @@ import json
 import os
 from tqdm import tqdm
 
-from pyserini.search import get_topics
+from pyserini.search import get_topics, get_topics_with_reader
 from pyserini.search.lucene import LuceneSearcher
 from pyserini.eval.evaluate_dpr_retrieval import has_answers, SimpleTokenizer
 
 if __name__ == '__main__':
     parser = argparse.ArgumentParser(description='Convert an TREC run to DPR retrieval result json.')
-    parser.add_argument('--topics', required=True, help='topic name')
+    parser.add_argument('--topics', help='topic name')
+    parser.add_argument('--topics-file', help='path to a topics file')
+    parser.add_argument('--topics-reader', help='anserini TopicReader class')
     parser.add_argument('--index', required=True, help='Anserini Index that contains raw')
     parser.add_argument('--input', required=True, help='Input TREC run file.')
     parser.add_argument('--store-raw', action='store_true', help='Store raw text of passage')
@@ -33,7 +35,12 @@ if __name__ == '__main__':
     parser.add_argument('--output', required=True, help='Output DPR Retrieval json file.')
     args = parser.parse_args()
 
-    qas = get_topics(args.topics)
+    if args.topics_file:
+        qas = get_topics_with_reader(args.topics_reader, args.topics_file)
+    elif args.topics:
+        qas = get_topics(args.topics)
+    else:
+        print("No topics file or topics name was provided")
 
     if os.path.exists(args.index):
         searcher = LuceneSearcher(args.index)
