@@ -129,6 +129,14 @@ topics_mapping = {
     'dpr-wq-test': JTopics.DPR_WQ_TEST,
     'dpr-squad-test': JTopics.DPR_SQUAD_TEST,
     'dpr-curated-test': JTopics.DPR_CURATED_TEST,
+    'dpr-trivia-test-gar-t5-answers': JTopics.DPR_TRIVIA_TEST_GART5_ANSWERS,
+    'dpr-trivia-test-gar-t5-titles': JTopics.DPR_TRIVIA_TEST_GART5_TITLES,
+    'dpr-trivia-test-gar-t5-sentences': JTopics.DPR_TRIVIA_TEST_GART5_SENTENCES,
+    'dpr-trivia-test-gar-t5-all': JTopics.DPR_TRIVIA_TEST_GART5_ALL,
+    'nq-test-gar-t5-answers': JTopics.NQ_TEST_GART5_ANSWERS,
+    'nq-test-gar-t5-titles': JTopics.NQ_TEST_GART5_TITLES,
+    'nq-test-gar-t5-sentences': JTopics.NQ_TEST_GART5_SENTENCES,
+    'nq-test-gar-t5-all': JTopics.NQ_TEST_GART5_ALL,
     'nq-dev': JTopics.NQ_DEV,
     'nq-test': JTopics.NQ_TEST,
     'mrtydi-v1.1-arabic-train': JTopics.MRTYDI_V11_AR_TRAIN,
@@ -277,6 +285,8 @@ topics_mapping = {
     'miracl-v1.0-te-dev': JTopics.MIRACL_V10_TE_DEV,
     'miracl-v1.0-th-dev': JTopics.MIRACL_V10_TH_DEV,
     'miracl-v1.0-zh-dev': JTopics.MIRACL_V10_ZH_DEV,
+    'miracl-v1.0-de-dev': JTopics.MIRACL_V10_DE_DEV,
+    'miracl-v1.0-yo-dev': JTopics.MIRACL_V10_YO_DEV,
 }
 
 qrels_mapping = {
@@ -417,6 +427,8 @@ qrels_mapping = {
     'miracl-v1.0-te-dev': JQrels.MIRACL_V10_TE_DEV,
     'miracl-v1.0-th-dev': JQrels.MIRACL_V10_TH_DEV,
     'miracl-v1.0-zh-dev': JQrels.MIRACL_V10_ZH_DEV,
+    'miracl-v1.0-de-dev': JQrels.MIRACL_V10_DE_DEV,
+    'miracl-v1.0-yo-dev': JQrels.MIRACL_V10_YO_DEV,
 }
 
 
