@@ -444,7 +444,50 @@ class TestLoadTopics(unittest.TestCase):
         self.assertEqual(len(topics), 8837)
         self.assertTrue(isinstance(next(iter(topics.keys())), int))
 
-    # TREC-COVID
+    # GarT5 topics
+    def test_gart5_nq_test(self):
+        topics = search.get_topics('nq-test-gar-t5-answers')
+        self.assertIsNotNone(topics)
+        self.assertEqual(len(topics), 3610)
+        self.assertTrue(isinstance(next(iter(topics.keys())), int))
+
+        topics = search.get_topics('nq-test-gar-t5-titles')
+        self.assertIsNotNone(topics)
+        self.assertEqual(len(topics), 3610)
+        self.assertTrue(isinstance(next(iter(topics.keys())), int))
+
+        topics = search.get_topics('nq-test-gar-t5-sentences')
+        self.assertIsNotNone(topics)
+        self.assertEqual(len(topics), 3610)
+        self.assertTrue(isinstance(next(iter(topics.keys())), int))
+
+        topics = search.get_topics('nq-test-gar-t5-all')
+        self.assertIsNotNone(topics)
+        self.assertEqual(len(topics), 3610)
+        self.assertTrue(isinstance(next(iter(topics.keys())), int))
+
+    def test_gart5_trivia_test(self):
+        topics = search.get_topics('dpr-trivia-test-gar-t5-answers')
+        self.assertIsNotNone(topics)
+        self.assertEqual(len(topics), 11313)
+        self.assertTrue(isinstance(next(iter(topics.keys())), int))
+
+        topics = search.get_topics('dpr-trivia-test-gar-t5-titles')
+        self.assertIsNotNone(topics)
+        self.assertEqual(len(topics), 11313)
+        self.assertTrue(isinstance(next(iter(topics.keys())), int))
+
+        topics = search.get_topics('dpr-trivia-test-gar-t5-sentences')
+        self.assertIsNotNone(topics)
+        self.assertEqual(len(topics), 11313)
+        self.assertTrue(isinstance(next(iter(topics.keys())), int))
+
+        topics = search.get_topics('dpr-trivia-test-gar-t5-all')
+        self.assertIsNotNone(topics)
+        self.assertEqual(len(topics), 11313)
+        self.assertTrue(isinstance(next(iter(topics.keys())), int))
+
+    # TREC-COVID    
     def test_covid_round1(self):
         topics = search.get_topics('covid-round1')
         self.assertIsNotNone(topics)
@@ -1102,6 +1145,16 @@ class TestLoadTopics(unittest.TestCase):
         self.assertEqual(len(topics), 393)
         self.assertTrue(isinstance(next(iter(topics.keys())), str))
 
+        topics = search.get_topics('miracl-v1.0-de-dev')
+        self.assertIsNotNone(topics)
+        self.assertEqual(len(topics), 305)
+        self.assertTrue(isinstance(next(iter(topics.keys())), str))
+
+        topics = search.get_topics('miracl-v1.0-yo-dev')
+        self.assertIsNotNone(topics)
+        self.assertEqual(len(topics), 119)
+        self.assertTrue(isinstance(next(iter(topics.keys())), str))
+
     # General test cases
     def test_tsv_int_topicreader(self):
         # Running from command-line, we're in root of repo, but running in IDE, we're in tests/
@@ -1130,7 +1183,11 @@ class TestLoadTopics(unittest.TestCase):
         self.assertEqual(search.get_topics('robust04'), topics)
 
     def test_trec_topicreader_nonint_qid(self):
+        # Running from command-line, we're in root of repo, but running in IDE, we're in tests/
         path = 'tests/resources/sample_queries_nonint_qid.tsv'
+        if not os.path.exists(path):
+            path = f'../{path}'
+
         self.assertTrue(os.path.exists(path))
         topics = search.get_topics_with_reader('io.anserini.search.topicreader.TsvStringTopicReader', path)
         self.assertEqual(len(topics), 3)
